:mod:`art.estimators.object_detection`
======================================
.. automodule:: art.estimators.object_detection

Mixin Base Class Object Detector
--------------------------------
.. autoclass:: ObjectDetectorMixin
   :members:
   :special-members: __init__
   :inherited-members:

Object Detector PyTorch Faster-RCNN
-----------------------------------
.. autoclass:: PyTorchFasterRCNN
   :members:
   :special-members: __init__
   :inherited-members:

Object Detector TensorFlow Faster-RCNN
--------------------------------------
.. autoclass:: TensorFlowFasterRCNN
   :members:
   :special-members: __init__
   :inherited-members:
